@@ -4,12 +4,14 @@
 
 import time
 import board
-from adafruit_lc709203f import LC709023F
+from adafruit_lc709203f import LC709203F
 
-print("LC709023F simple test")
+print("LC709203F simple test")
 print("Make sure LiPoly battery is plugged into the board!")
 
-sensor = LC709023F(board.I2C())
+i2c = board.I2C()  # uses board.SCL and board.SDA
+# i2c = board.STEMMA_I2C()  # For using the built-in STEMMA QT connector on a microcontroller
+sensor = LC709203F(i2c)
 
 print("IC version:", hex(sensor.ic_version))
 while True:
